@@ -140,10 +140,6 @@ int *match[4];
    memcpy
        ((POINTER)&context->buffer[index], (POINTER)bits, partLen);
    MD5OLDTransform(context->state, context->buffer);
-#ifndef INF64 
-   for (i = partLen; i + 63 < inputLen; i += 64)
-      MD5OLDTransform(context->state, input+i);
-#endif
    index = 0;
 
 
@@ -299,11 +295,19 @@ unsigned int len;
   ord32	b;
   ord32	c;
   ord32	d;
+#ifdef ISBIG_ENDIAN
+  ord32 x[6];
+#else
   ord32* x;
+#endif
   
   static ord32 fasta, fastb, fastc, fastd;
 
+#ifdef ISBIG_ENDIAN
+  Decode(x, block, 24);
+#else
   x = (ord32 *)block;
+#endif
 
   b = 0xefcdab89;
   c = 0x98badcfe;
